@@ -1,13 +1,14 @@
 use crate::payload::SerializationResult;
+use bytes::Bytes;
 use serde::de::DeserializeOwned;
 use serde::Serialize;
 use std::io::Read;
 
 #[inline]
-pub fn serialize<T: Serialize>(data: T) -> SerializationResult<Vec<u8>> {
+pub fn serialize<T: Serialize>(data: T) -> SerializationResult<Bytes> {
     let bytes = rmp_serde::to_vec(&data)?;
 
-    Ok(bytes)
+    Ok(Bytes::from(bytes))
 }
 
 #[inline]
